==> NISP-2.2-2-src.zip: nisp/sci_gateway/cpp/sci_polychaos_settarget.cpp <==

// Copyright (C) 2008 - INRIA - Michael Baudin
// Copyright (C) 2009 - Digiteo - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

extern "C" {
#include "stack-c.h" 
#include "Scierror.h"
#include "localization.h"
#include "gw_nisp.h"
}


/* ==================================================================== */

#include "nisp_gwsupport.hxx" 
#include "nisp_PolynomialChaos_map.hxx" 


/* ==================================================================== */
// 
// polychaos_settarget ( token , k , j , output )
//   set the output value for experiment #k and output #j, where k = 1, np and j=1,ny
// polychaos_settarget ( token , k , output ) 
//   set the output #k with 1<= k<= np, where np is the number of simulations 
//   where output is a matrix with size 1 x (ny)
// polychaos_settarget ( token , output ) 
//   set the output matrix where output is a matrix with size (np) x (ny)
//
int sci_polychaos_settarget (char *fname)
{
	int m, n;
	int token;
	PolynomialChaos * pc = NULL;
	double * outputVector = NULL;
	int k;
	int j;
	double output;
	int ny;
	int np;

	CheckRhs(2,4) ;
	CheckLhs(0,1) ;
	nisp_gettoken ( fname , 1 , & token );
	if ( (Rhs == 2) ) {
		// polychaos_settarget ( token , output ) 
		//
		// Get output
		//
		if ( GetType(2) != sci_matrix )
		{
			Scierror(204,_("%s: Wrong type for input argument #%d: Double expected.\n"),fname,2);
			return 0;
		}
		GetRhsVarMatrixDouble(2, &m, &n, &outputVector);
	}
	if ( (Rhs == 3) | (Rhs == 4) ) {
		// polychaos_settarget ( token , k , output ) 
		// polychaos_settarget ( token , k , j , output )
		nisp_GetOneInteger ( fname , 2 , &k );
	}
	if ( (Rhs == 3) ) {
		// polychaos_settarget ( token , k , output ) 
		//
		// Get output
		//
		if ( GetType(3) != sci_matrix )
		{
			Scierror(204,_("%s: Wrong type for input argument #%d: Double expected.\n"),fname,3);
			return 0;
		}
		GetRhsVarMatrixDouble(3, &m, &n, &outputVector);
	}
	else if ( (Rhs == 4) ) {
		// polychaos_settarget ( token , k , j , output )
		nisp_GetOneInteger ( fname , 3 , &j );
		nisp_GetOneDouble ( fname , 4 , &output );
	}
	nisp_token2Polychaos ( fname , 1 , token , &pc );
	if ( (Rhs == 2) ) {
		// polychaos_settarget ( token , output ) 
		ny = pc -> GetDimensionOutput ();
		np = pc -> GetSizeTarget ();
		// Check that outputVector's size matches PolynomialChaos's np
		if ( m != np )
		{
			Scierror(999,_("%s: Wrong number of rows in argument #%d: found %d rows but %d row expected.\n"),fname,2, m , np );
			return 0;
		}
		if ( n != ny )
		{
			Scierror(999,_("%s: Wrong number of columns in argument #%d: found %d rows but %d row expected.\n"),fname,2 , n , ny );
			return 0;
		}
		for(int j=1;j<=ny;j++) {
			for(int k=1;k<=np;k++) {
				pc -> SetTarget ( k, j, *(outputVector + (j-1) * np + (k-1)) );
			}
		}
	} else if ( (Rhs == 3) ) {
		// polychaos_settarget ( token , k , output ) 
		ny = pc -> GetDimensionOutput ();
		// Check that outputVector's size matches PolynomialChaos's ny
		if ( m != 1 )
		{
			Scierror(999,_("%s: Wrong number of rows in argument #%d: found %d rows but 1 row expected.\n"),fname,3, m );
			return 0;
		}
		if ( n != ny )
		{
			Scierror(999,_("%s: Wrong number of columns in argument #%d: found %d rows but %d row expected.\n"),fname,3 , n , ny );
			return 0;
		}
		// Set target
		for(int j=1;j<=ny;j++) {
			pc -> SetTarget ( k, j, outputVector[j-1] );
		}
	} else if ( (Rhs == 4) ) {
		// polychaos_settarget ( token , k , j , output )
		// Set target
		pc -> SetTarget ( k, j, output );
	}
	// Returns the token as the result
	nisp_CreateLhsInteger ( 1 , token );
	return 0;
}
/* ==================================================================== */

==> NISP-2.4.1-1-src.zip: nisp/sci_gateway/cpp/sci_polychaos_settarget.cpp <==

// Copyright (C) 2008 - INRIA - Michael Baudin
// Copyright (C) 2009 - Digiteo - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

extern "C" {
#include "stack-c.h" 
#include "Scierror.h"
#include "localization.h"
#include "gw_nisp.h"
}


/* ==================================================================== */

#include "nisp_gwsupport.hxx" 
#include "nisp_PolynomialChaos_map.hxx" 


/* ==================================================================== */
// 
// polychaos_settarget ( token , k , j , output )
//   set the output value for experiment #k and output #j, where k = 1, np and j=1,ny
// polychaos_settarget ( token , k , output ) 
//   set the output #k with 1<= k<= np, where np is the number of simulations 
//   where output is a matrix with size 1 x (ny)
// polychaos_settarget ( token , output ) 
//   set the output matrix where output is a matrix with size (np) x (ny)
//
int sci_polychaos_settarget (char *fname)
{
	int m, n;
	int token;
	PolynomialChaos * pc = NULL;
	double * outputVector = NULL;
	int k;
	int j;
	double output;
	int ny;
	int np;

	CheckRhs(2,4) ;
	CheckLhs(0,1) ;
	nispgw_gettoken ( fname , 1 , & token );
	if ( (Rhs == 2) ) {
		// polychaos_settarget ( token , output ) 
		//
		// Get output
		//
		if ( GetType(2) != sci_matrix )
		{
			Scierror(204,_("%s: Wrong type for input argument #%d: Double expected.\n"),fname,2);
			return 0;
		}
		GetRhsVarMatrixDouble(2, &m, &n, &outputVector);
	}
	if ( (Rhs == 3) | (Rhs == 4) ) {
		// polychaos_settarget ( token , k , output ) 
		// polychaos_settarget ( token , k , j , output )
		nispgw_GetOneInteger ( fname , 2 , &k );
	}
	if ( (Rhs == 3) ) {
		// polychaos_settarget ( token , k , output ) 
		//
		// Get output
		//
		if ( GetType(3) != sci_matrix )
		{
			Scierror(204,_("%s: Wrong type for input argument #%d: Double expected.\n"),fname,3);
			return 0;
		}
		GetRhsVarMatrixDouble(3, &m, &n, &outputVector);
	}
	else if ( (Rhs == 4) ) {
		// polychaos_settarget ( token , k , j , output )
		nispgw_GetOneInteger ( fname , 3 , &j );
		nispgw_GetOneDouble ( fname , 4 , &output );
	}
	nispgw_token2Polychaos ( fname , 1 , token , &pc );
	if ( (Rhs == 2) ) {
		// polychaos_settarget ( token , output ) 
		ny = pc -> GetDimensionOutput ();
		np = pc -> GetSizeTarget ();
		// Check that outputVector's size matches PolynomialChaos's np
		if ( m != np )
		{
			Scierror(999,_("%s: Wrong number of rows in argument #%d: found %d rows but %d row expected.\n"),fname,2, m , np );
			return 0;
		}
		if ( n != ny )
		{
			Scierror(999,_("%s: Wrong number of columns in argument #%d: found %d rows but %d row expected.\n"),fname,2 , n , ny );
			return 0;
		}
		for(int j=1;j<=ny;j++) {
			for(int k=1;k<=np;k++) {
				pc -> SetTarget ( k, j, *(outputVector + (j-1) * np + (k-1)) );
			}
		}
	} else if ( (Rhs == 3) ) {
		// polychaos_settarget ( token , k , output ) 
		ny = pc -> GetDimensionOutput ();
		// Check that outputVector's size matches PolynomialChaos's ny
		if ( m != 1 )
		{
			Scierror(999,_("%s: Wrong number of rows in argument #%d: found %d rows but 1 row expected.\n"),fname,3, m );
			return 0;
		}
		if ( n != ny )
		{
			Scierror(999,_("%s: Wrong number of columns in argument #%d: found %d rows but %d row expected.\n"),fname,3 , n , ny );
			return 0;
		}
		// Set target
		for(int j=1;j<=ny;j++) {
			pc -> SetTarget ( k, j, outputVector[j-1] );
		}
	} else if ( (Rhs == 4) ) {
		// polychaos_settarget ( token , k , j , output )
		// Set target
		pc -> SetTarget ( k, j, output );
	}
	// Returns the token as the result
	nispgw_CreateLhsInteger ( 1 , token );
	return 0;
}
/* ==================================================================== */
